package App::ctransition ;  
our $VERSION = '0.003' ; 
our $DATE = '2024-03-16T11:40+09:00' ; 

=encoding utf8

=head1 NAME

App::ctransition -- 入力の全ての文字に対して、次の文字は何であるかの回数の集計を、行列状に表示する。

=head1 SYNOPSIS

This module provides a Unix-like command `F<ctransition>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

=head1 AUTHOR

Toshiyuki Shimono (Advanced Collaborative Research Organization for Smart Society, Waseda University)

=cut

1 ;
